==> 0.3.19.tar.gz: android/src/main/java/com/samelement/iot_notification/appwidget/DashboardsAdapter.java <==
package com.samelement.iot_notification.appwidget;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.samelement.iot_notification.analytic.Analytic;

import java.util.List;

public class DashboardsAdapter extends ArrayAdapter<Analytic> {

    private Context context;
    private List<Analytic> analyticList;

    DashboardsAdapter(@NonNull Context context, int resource, @NonNull List<Analytic> objects) {
        super(context, resource, objects);

        this.analyticList = objects;
        this.context = context;
    }

    @NonNull
    @Override
    public View getView(int position, @Nullable View convertView, @NonNull ViewGroup parent) {
        ViewHolder viewHolder;

        if (convertView == null) {
            // inflate the layout
            convertView = LayoutInflater.from(context).inflate(android.R.layout.simple_list_item_1, parent, false);

            // well set up the ViewHolder
            viewHolder = new ViewHolder();
            viewHolder.title = convertView.findViewById(android.R.id.text1);

            // store the holder with the view.
            convertView.setTag(viewHolder);
        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }

        Analytic currentAnalytic = analyticList.get(position);
        if (currentAnalytic != null) {
            viewHolder.title.setText(currentAnalytic.getTitle());
        }

        return convertView;
    }

    static class ViewHolder {
        TextView title;
    }
}

==> 0.5.5.tar.gz: android/src/main/java/com/samelement/iot_notification/appwidget/DashboardsAdapter.java <==
package com.samelement.iot_notification.appwidget;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.samelement.iot_notification.analytic.Analytic;

import java.util.List;

public class DashboardsAdapter extends ArrayAdapter<Analytic> {

    private final Context context;
    private final List<Analytic> analyticList;

    DashboardsAdapter(@NonNull Context context, int resource, @NonNull List<Analytic> objects) {
        super(context, resource, objects);

        this.analyticList = objects;
        this.context = context;
    }

    @NonNull
    @Override
    public View getView(int position, @Nullable View convertView, @NonNull ViewGroup parent) {
        ViewHolder viewHolder;

        if (convertView == null) {
            // inflate the layout
            convertView = LayoutInflater.from(context).inflate(android.R.layout.simple_list_item_1, parent, false);

            // well set up the ViewHolder
            viewHolder = new ViewHolder();
            viewHolder.title = convertView.findViewById(android.R.id.text1);

            // store the holder with the view.
            convertView.setTag(viewHolder);
        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }

        Analytic currentAnalytic = analyticList.get(position);
        if (currentAnalytic != null) {
            viewHolder.title.setText(currentAnalytic.getTitle());
        }

        return convertView;
    }

    static class ViewHolder {
        TextView title;
    }
}
